<?php

namespace App\Helpers;

use Illuminate\Support\Facades\DB;

class AccessLevelHelper
{
  public static function getDefaultAccessGroups () {
    $access_groups = [];
    $positions = DB::table('position')->select()->get();

    foreach ($positions as $position) {
      $job = DB::table('job')->select()->where('job_id', $position->fk_job)->first();

      if (isset($access_groups[$job->job_short_value])) {
        if ($position->position_access_group == "responsables-apprentis") {
          array_push($access_groups[$job->job_short_value], ["position" => $position->position_access_group, "role" => "responsable"]);
        } else {
          array_push($access_groups[$job->job_short_value], ["position" => $position->position_access_group, "role" => "formateur"]);
        }
      } else {
        if ($position->position_access_group == "responsables-apprentis") {
          $access_groups[$job->job_short_value][0] = ["position" => $position->position_access_group, "role" => "responsable"];
        } else {
          $access_groups[$job->job_short_value][0] = ["position" => $position->position_access_group, "role" => "formateur"];
        }
      }
    }
    return $access_groups;
  }

  public static function hasAccessToJob($job, $permissions)
  {
    return in_array($job, $permissions);
  }

  public static function isJobValid($job)
  {
    $default_access_groups = self::getDefaultAccessGroups();
    foreach ($default_access_groups as $access_job => $access) {
      if ($access_job == $job) {
        return true;
      }
    }
    return false;
  }

  public static function hasPermittedRole($user_role, $wanted_role)
  {
    return $user_role == $wanted_role;
  }

  public static function getUserAccess($user_groups)
  {
    $default_access_groups = self::getDefaultAccessGroups();
    $user_alloweds = [];
    $user_role = 'formateur'; // formateur
    $user_groups = explode(',', $user_groups);

    foreach ($default_access_groups as $group => $accesses) {
      foreach ($accesses as $access) {
        if ((in_array($access['position'], $user_groups))) {
          if (self::hasPermittedRole($access['position'], "formateur")) {
            $user_role = "responsable";
          }
          array_push($user_alloweds, $group);
        }
      }
    }
    return ["groups" => array_unique($user_alloweds), "role" => $user_role];
  }
}