<?php

namespace App\Http\Controllers;

use Laravel\Lumen\Routing\Controller;
use Illuminate\Http\Request;
use App\Providers\TequilaClient;
use Firebase\JWT\JWT;
use App\Helpers\AccessLevelHelper;

class AuthController extends Controller
{
  private $request;
  private $oClient;

  public function __construct(Request $request)
  {
    $this->request = $request;
  }

  protected function jwt($tequilaObject)
  {
    $user_perms = AccessLevelHelper::getUserAccess($tequilaObject->getValue("group"));
    $payload = [
      'iss' => "canap-gest",
      'sub' => $tequilaObject->getValue('uniqueid'),
      "tequila_data" => [
        "firstname" => $tequilaObject->getValue('firstname'),
        "name" => $tequilaObject->getValue("name"),
        "group" => $tequilaObject->getValue("group"),
        "user" => $tequilaObject->getValue("user"),
        "sciper" => $tequilaObject->getValue('uniqueid')
      ],
      'permissions' => $user_perms['groups'],
      "role" => $user_perms['role'],
      'iat' => time(),
      'exp' => time() + 43200
    ];

    return JWT::encode($payload, env('JWT_SECRET'));
  }

  public function authenticate()
  {
    $oClient = new TequilaClient();
    $oClient->SetApplicationName('Canap-Gest');
    $oClient->SetWantedAttributes(array('uniqueid', 'name', 'firstname', 'where', 'group'));
    $oClient->SetWishedAttributes(array('email', 'title'));
    $oClient->SetCustomFilter('org=EPFL&group=canap-gest-users-dev');
    // $this->oClient->SetApplicationURL('https://canap-gest.epfl.ch:8443');
    // $this->oClient->SetApplicationURL('localhost:8000/api/auth/login');
    $oClient->SetApplicationURL('http://canap-gest-dev.local:8080');
    $oClient->Authenticate();

    return response()->json([
      'token' => $this->jwt($oClient)
    ], 200);
  }

  public function logout()
  {
    $this->oClient->Logout();
  }
}
